/* This code was designed to create an Outlook toolbarwith buttons using and documenting 
 * the FaceId property. As, within Outlook, a toolbar seems to be only able to be a single-line
 * of buttons, it is only reasonable to show about 100 at a time (and this will still be much
 * more than one screen wide). If you want to see other indexes than those starting from zero,
 * change the offset constant
 * 
 * NJR 2006 http://www.kebabShopBlues.co.uk
 * 
 * Use as follows:
 * 1. Set the offset constant, and press F5 to run Outlook with the plugin;
 * 2. If it is not already, move the new (extremely long - it has 104 icons) toolbar onto the toolbar area. It will probably need
 *    to be at the extreme left side of the toolbar area;
 * 3. Resize your Outlook window so only four icons are showing in the test toolbar;
 * 4. Click the drop-down button at the right side of the toolbar, and a drop-down with all the 'non-displayed' numbers and icons will be shown;
 * 5. <Prt Sc> to copy the screen to the clipbpard, and use a graphics package to crop it;
 * 6. Go back to (1) and repeat with an offset 100 larger.
 */

using System;
using System.Windows.Forms;
using Microsoft.VisualStudio.Tools.Applications.Runtime;
using Outlook = Microsoft.Office.Interop.Outlook;
using Office = Microsoft.Office.Core;

namespace TestOutlookFaceId
{
    public partial class ThisApplication
    {
        const string COMMAND_BAR_TITLE = "TestOutlookFaceId";
        Outlook.Explorer explorer;
        Office.CommandBars bars;
        Office.CommandBar bar;
        Office.CommandBarButton[] button = new Microsoft.Office.Core.CommandBarButton[100];

        // TODO: CHANGE THE OFFSET CONSTANT HERE to get different icons
        const int offset = 4000;

        private void ThisApplication_Startup(object sender, System.EventArgs e)
        {
            buildCommandBar();

            // For various reasons, I want to repeat the first four buttons
            for (int i = 0; i < 4; i++)
            {
                // For the second parameter, add an offset if you want to see
                //  icons with different numbering than the index of the button[] array
                addButton(i, offset + i);
            }



            for (int i = 0; i < button.Length; i++)
            {
                // For the second parameter, add an offset if you want to see
                //  icons with different numbering than the index of the button[] array
                addButton(i, offset + i);
            }
        }

        private void ThisApplication_Shutdown(object sender, System.EventArgs e)
        {
        }

        /// <summary>
        /// Create the command bar for the application
        /// </summary>
        private void buildCommandBar()
        {
            explorer = this.ActiveExplorer();
            bars = explorer.CommandBars;

            //MessageBox.Show("I will build a command bar now");
            bar = bars.Add(COMMAND_BAR_TITLE, Office.MsoBarPosition.msoBarTop, missing, true);
            bar.Visible = true;

        }

        void addButton(int index, int faceId)
        {
            button[index] = bar.Controls.Add(Office.MsoControlType.msoControlButton, missing, missing, missing, true) as Office.CommandBarButton;
            button[index].Style = Microsoft.Office.Core.MsoButtonStyle.msoButtonIconAndCaption;
            button[index].Caption = faceId.ToString("0000") + "  ";
            button[index].FaceId = faceId;
            button[index].Tag = COMMAND_BAR_TITLE + "." + faceId.ToString();
        }


        #region VSTO generated code

        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InternalStartup()
        {
            this.Startup += new System.EventHandler(ThisApplication_Startup);
            this.Shutdown += new System.EventHandler(ThisApplication_Shutdown);
        }

        #endregion
    }
}
